stytch_codecs
Shared types used to construct requests to or responses from the Stytch authentication service.
Currently contains all types needed to support magic link and one time passcode authentication requests.
This package isn’t very useful on its own; it is meant to share types between JS frontend and JS or Erlang backend code. Use it in conjunction with the stytch_client package in your backend and/or the (not yet published to hex) stytch_ui_model in your frontend
See examples in the stytch_in_gleam monorepo.